# python active versions


[![pypi](https://img.shields.io/pypi/v/python-active-versions.svg)](https://pypi.org/project/python-active-versions/)
[![python](https://img.shields.io/pypi/pyversions/python-active-versions.svg)](https://pypi.org/project/python-active-versions/)
[![Build Status](https://github.com/gpongelli/python-active-versions/actions/workflows/dev.yml/badge.svg)](https://github.com/gpongelli/python-active-versions/actions/workflows/dev.yml)
[![codecov](https://codecov.io/gh/gpongelli/python-active-versions/branch/main/graphs/badge.svg)](https://codecov.io/github/gpongelli/python-active-versions)



Gather active python versions and, optionally, also docker images.


* Documentation: <https://gpongelli.github.io/python-active-versions>
* GitHub: <https://github.com/gpongelli/python-active-versions>
* PyPI: <https://pypi.org/project/python-active-versions/>
* Free software: MIT


## Features

* Scrape official python website to get active versions
* Scrape dockerhub website to add optional python's available images

## Credits

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [gpongelli/cookiecutter-pypackage](https://github.com/gpongelli/cookiecutter-pypackage) project template.
